package ttt.gui;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;

import ttt.model.Player;
import ttt.model.TTTGame;

import java.util.*;

/** The "crappy" normal view that draws X and O as images. */
public class TTTCrapView extends TTTView implements ActionListener {
    private static final long serialVersionUID = 0;

    // fields
    private JButton[][] squares;
    private SoundPlayer sound;
    
    public TTTCrapView(TTTGame game) {
        super(game);
        sound = new SoundPlayer();
        
        // 3x3 grid of buttons
        setLayout(new GridLayout(TTTGame.BOARD_SIZE, TTTGame.BOARD_SIZE, 5, 5));
        setBackground(Color.BLACK);
        
        squares = new JButton[TTTGame.BOARD_SIZE][TTTGame.BOARD_SIZE];
        for (int r = 0; r < TTTGame.BOARD_SIZE; r++) {
            for (int c = 0; c < TTTGame.BOARD_SIZE; c++) {
                squares[r][c] = GuiWidgetFactory.createButton("", this, this);
                squares[r][c].setBorderPainted(false);
            }
        }
        
        setButtons();
    }
    
    /** Called when buttons are clicked in this panel. */
    public void actionPerformed(ActionEvent event) {
        // when they click the button, do this:
        for (int r = 0; r < TTTGame.BOARD_SIZE; r++) {
            for (int c = 0; c < TTTGame.BOARD_SIZE; c++) {
                if (squares[r][c] == event.getSource()) {
                    // they clicked button [r, c]
                    game.play(r, c);
                }
            }
        }
    }
    
    /** Called by the observable model when updates occur. */
    public void update(Observable o, Object arg) {
        // sound code
        if (arg != null) {
            sound.play(SOUND_FOLDER + arg + ".wav");
        }
        
        setButtons();
    }
    
    /** updates all buttons' text */
    private void setButtons() {
        for (int r = 0; r < TTTGame.BOARD_SIZE; r++) {
            for (int c = 0; c < TTTGame.BOARD_SIZE; c++) {
                Player square = game.getSquare(r, c);
                if (square == TTTGame.EMPTY) {
                    squares[r][c].setIcon(null);
                } else {
                    squares[r][c].setIcon(new ImageIcon(IMAGE_FOLDER + square + ".jpg"));
                }
            }
        }
    }
}
